@@ -9,7 +9,7 @@ use Carp qw( croak carp );
 use POSIX ":sys_wait_h";
 use IO::Pipe;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub new {
     my $class = shift;
@@ -296,6 +296,13 @@ sub message {
     kill( 'URG', $pid ) or carp("Failed to signal process $pid to new message");
 }
 
+our $AUTOLOAD;
+sub AUTOLOAD {
+    my $self = shift;
+    my $key = ( split( '::', $AUTOLOAD ) )[-1];
+    return $self->data($key);
+}
+
 1;
 
 __END__
@@ -310,7 +317,7 @@ Daemon::Device - Forking daemon device construct
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Daemon-Device.svg)](https://travis-ci.org/gryphonshafer/Daemon-Device)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Daemon-Device/badge.png)](https://coveralls.io/r/gryphonshafer/Daemon-Device)
@@ -609,6 +616,18 @@ parent's data when the spawning takes place. This is a copy, so changing data
 in one place does not change it elsewhere. Note also that in some cases you
 can't guarentee the exact order or timing of spawning children.
 
+=head2 Helper Methods
+
+As a convenience, you can access any single data value by referencing a method
+of the same name.
+
+    $device->data(
+        noun => 'World',
+        hi   => sub { say "Hello $_[0]" },
+    );
+
+    say $device->hi( $device->noun );
+
 =head1 MESSAGING
 
 You can, of course, setup whatever interprocess communications you'd like. In
